{==============================================================================|
| Project : Notes/Delphi class library                           | 3.9.1       |
|==============================================================================|
| Content:                                                                     |
|==============================================================================|
| The contents of this file are subject to the Mozilla Public License Ver. 1.0 |
| (the "License"); you may not use this file except in compliance with the     |
| License. You may obtain a copy of the License at http://www.mozilla.org/MPL/ |
|                                                                              |
| Software distributed under the License is distributed on an "AS IS" basis,   |
| WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for |
| the specific language governing rights and limitations under the License.    |
|==============================================================================|
| Initial Developers of the Original Code are:                                 |
|   Sergey Kolchin (Russia) skolchin@yahoo.com                                 |
|   Winalot
| All Rights Reserved.                                                         |
|   Last Modified:                                                             |
|     25.08.01                                                                 |
|==============================================================================|
| Contributors and Bug Corrections:                                            |
|==============================================================================|
| History: see README.TXT                                                      |
|==============================================================================|
| Translation of Notes FAX API, which allows to send/process faxes. Made as a  |
| separate unit in order to maintain compatibility with prior Notes versions   |
| The API was introduced in R5, but seems it was silently included into R4.6   |
|==============================================================================|}
unit Util_LnFaxApi;

interface
uses Windows, Util_LnApi, Util_LnApiErr, Class_LotusNotes, Class_NotesRTF;


const
  EDIT_FAX_DLL_NAME = 'neditfax.dll';

//* Data structures used when printing to a bitmap */

type
  EPBCONTEXT = record
    Proc: FARPROC;        //* Callback procedure of type EPBPROC*/
    hPaint: HDC;          //* hPS that the bitmap can be selected into */
    hBitmap: HBITMAP;     //* Bitmap to paint into */
    BitmapSize: RECTSIZE; //* Size of the bitmap */
    PaintRect: TRECT;     //* Rectangle within the bitmap into which to paint */
    cxPaperTwips: WORD;   //* Width of the paper, in TWIPS */
    cyPaperTwips: WORD;   //* Height of the paper, in TWIPS */
  end;
  PEPBCONTEXT = ^EPBCONTEXT;

  EPBPROC = function (EPBContext: PEPBCONTEXT; PageNumber: WORD): BOOL; stdcall;


function EditorPrintNoteToBitmap (
                      hDB: DBHANDLE;
                      NoteID: NOTEID;
                      EPBContext: PEPBCONTEXT): STATUS; stdcall; far;

function EditorAppendBitmapToNote (
                      hBitmap: HBITMAP;
                      cxPaperTwips: WORD;
                      cyPaperTwips: WORD;
                      DisplayScalingPercent: WORD;
                      hNote: NOTEHANDLE;
                      ItemFlags: WORD;
                      ItemName: pchar;
                      ItemNameLength: WORD;
                      ParagraphAttributes: Pointer): STATUS; stdcall; far;

// More high level functions

procedure PrintNoteToBitmap(Note: TNotesDocument; var Context: EPBCONTEXT);
procedure AppendBitmapToNote(hBitmap: HBITMAP;
                      cxPaperTwips: WORD;
                      cyPaperTwips: WORD;
                      DisplayScalingPercent: WORD;
                      Item: TNotesRichTextItem);

implementation

function EditorPrintNoteToBitmap; stdcall; far; external EDIT_FAX_DLL_NAME;

function EditorAppendBitmapToNote; stdcall; far; external EDIT_FAX_DLL_NAME;


procedure PrintNoteToBitmap;
begin
  CheckError(EditorPrintNoteToBitmap(Note.Database.Handle, Note.DocID, @Context));
end;

procedure AppendBitmapToNote;
begin
  // Use paragraph set in the item
  CheckError(EditorAppendBitmapToNote(hBitmap, cxPaperTwips, cyPaperTwips, DisplayScalingPercent,
    Item.Document.Handle, Item.ItemFlags, pchar(Item.Name), length(Item.Name), nil));
end;


end.
